==> dde-network-core_2.0.60.tar.xz: BUILD/dss-network-plugin/translations/dss-network-plugin_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>Одно новое сообщение</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Если вы хотите подключиться к беспроводной сети, сначала отключите &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Режим самолёта&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>%1 соединено</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>key</source>
        <translation>ключ</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Пароль прокси</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Имя (SSID)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Отключить беспроводное соединение</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Включите беспроводное соединение</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Отключить сеть</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Включить сеть</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation>Отключить VPN</translation>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation>Включить VPN</translation>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation>Отключить системный прокси</translation>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation>Включить системный прокси</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Настройки сети</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation>Запущено несколько сервисов</translation>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation>Включен системный прокси</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Подключено</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Сеть отключена</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, но нет доступа к Интернету</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ошибка подключения</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Off</source>
        <translation>Выкл.</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Системный прокси</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>Конфигурация VPN не подключена или не удалось подключиться. Пожалуйста, обратитесь в &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Центр управления&lt;/a&gt; для проверки.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Подключение к скрытой сети</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Мои сети</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Прочие сети</translation>
    </message>
</context>
</TS>

==> dde-network-core_2.0.71.tar.xz: BUILD/dss-network-plugin/translations/dss-network-plugin_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>Одно новое сообщение</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Если вы хотите подключиться к беспроводной сети, сначала отключите &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Режим полета&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Проводное соединение %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE соединение %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Соединение с &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; подключено</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; отключено</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>Невозможно подключиться к &quot;%1&quot;, проверьте маршрутизатор или сетевой кабель.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>Невозможно подключиться к &quot;%1&quot;, пожалуйста, держитесь ближе к беспроводному маршрутизатору</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Сбой подключения, не удается подключиться &quot;%1&quot;, неверный пароль</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Для соединения с &quot;%1&quot; требуется пароль</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>Не удалось найти сеть WLAN 802.11 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Чтобы подключиться к &quot;%1&quot;, пожалуйста, настройте данные для аутентификации</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Личный пароль</translation>
    </message>
    <message>
        <source>key</source>
        <translation>ключ</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Пароль прокси</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>Пароль группы</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Имя (SSID)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Подключить</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Отключить проводное соединение</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Включить проводное соединение</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Отключить беспроводное соединение</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Включите беспроводное соединение</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Отключить сеть</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Включить сеть</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation>Отключить VPN</translation>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation>Включить VPN</translation>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation>Отключить системный прокси</translation>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation>Включить системный прокси</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Настройки сети</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation>Запущено несколько сервисов</translation>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation>Подключено к: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation>Включен системный прокси</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Подключено</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Сеть отключена</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Сетевой кабель отключен</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Соединение</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Подключено, но нет доступа к Интернету</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Ошибка подключения</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфликт IP-адресов</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Подключено %1</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Выкл.</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Системный прокси</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>Конфигурация VPN не подключена или не удалось подключиться. Пожалуйста, обратитесь в &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Центр управления&lt;/a&gt; для проверки.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Проводная сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Беспроводная сеть</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Подключение к скрытой сети</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Мои сети</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Прочие сети</translation>
    </message>
</context>
</TS>
